# `narwhals.DataFrame`

::: narwhals.dataframe.DataFrame
    handler: python
    options:
      members:
        - columns
        - drop
        - drop_nulls
        - filter
        - group_by
        - head
        - is_duplicated
        - is_empty
        - is_unique
        - join
        - lazy
        - null_count
        - pipe
        - rename
        - schema
        - select
        - shape
        - sort
        - to_dict
        - to_numpy
        - to_pandas
        - unique
        - with_columns
        - with_row_index
      show_source: false
      show_bases: false
